@@ -55,14 +55,11 @@ ColorSchemeManager* ColorSchemeManager::instance()
 
 void ColorSchemeManager::loadAllColorSchemes()
 {
-    int success = 0;
     int failed = 0;
 
-    QStringList nativeColorSchemes = listColorSchemes();
-    foreach (const QString &colorScheme, nativeColorSchemes) {
-        if (loadColorScheme(colorScheme)) {
-            success++;
-        } else {
+    const QStringList nativeColorSchemes = listColorSchemes();
+    for (const QString &colorScheme : nativeColorSchemes) {
+        if (!loadColorScheme(colorScheme)) {
             failed++;
         }
     }
@@ -221,7 +218,7 @@ const ColorScheme *ColorSchemeManager::findColorScheme(const QString &name)
 
 QString ColorSchemeManager::findColorSchemePath(const QString &name) const
 {
-    QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("konsole/") + name + QLatin1String(".colorscheme"));
+    QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + name + QStringLiteral(".colorscheme"));
 
     if (!path.isEmpty()) {
         return path;
@@ -247,7 +244,7 @@ bool ColorSchemeManager::isColorSchemeDeletable(const QString &name)
 
 bool ColorSchemeManager::canResetColorScheme(const QString &name)
 {
-    const QStringList paths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QLatin1String("konsole/") + name + QLatin1String(".colorscheme"));
+    const QStringList paths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + name + QStringLiteral(".colorscheme"));
 
     // if the colorscheme exists in both a writable location under the
     // user's home dir and a system-wide location, then it's possible
