@@ -307,7 +307,7 @@ bool EditProfileDialog::isValidProfileName()
     const QList<Profile::Ptr> existingProfiles = ProfileManager::instance()->allProfiles();
     QStringList otherExistingProfileNames;
 
-    foreach(auto existingProfile, existingProfiles) {
+    for (const Profile::Ptr &existingProfile : existingProfiles) {
         if (existingProfile->name() != _profile->name()) {
             otherExistingProfileNames.append(existingProfile->name());
         }
@@ -507,7 +507,7 @@ void EditProfileDialog::showEnvironmentEditor()
     QString text = QInputDialog::getMultiLineText(this,
                                                   i18n("Edit Environment"),
                                                   i18n("One environment variable per line"),
-                                                  currentEnvironment.join(QLatin1Char('\n')),
+                                                  currentEnvironment.join(QStringLiteral("\n")),
                                                   &ok);
 
     QStringList newEnvironment;
@@ -722,16 +722,12 @@ void EditProfileDialog::setupAppearancePage(const Profile::Ptr &profile)
     }
 
     _appearanceUi->customColorSelectButton->setColor(profile->customCursorColor());
+    _appearanceUi->customTextColorSelectButton->setColor(profile->customCursorTextColor());
 
     connect(_appearanceUi->customCursorColorButton, &QRadioButton::clicked, this, &Konsole::EditProfileDialog::customCursorColor);
     connect(_appearanceUi->autoCursorColorButton, &QRadioButton::clicked, this, &Konsole::EditProfileDialog::autoCursorColor);
     connect(_appearanceUi->customColorSelectButton, &KColorButton::changed, this, &Konsole::EditProfileDialog::customCursorColorChanged);
-
-    // Make radio buttons height equal
-    int cursorColorRadioHeight = qMax(_appearanceUi->autoCursorColorButton->minimumSizeHint().height(),
-                                      _appearanceUi->customColorSelectButton->minimumSizeHint().height());
-    _appearanceUi->autoCursorColorButton->setMinimumHeight(cursorColorRadioHeight);
-    _appearanceUi->customCursorColorButton->setMinimumHeight(cursorColorRadioHeight);
+    connect(_appearanceUi->customTextColorSelectButton, &KColorButton::changed, this, &Konsole::EditProfileDialog::customCursorTextColorChanged);
 
     const ButtonGroupOptions cursorShapeOptions = {
         _appearanceUi->cursorShape, // group
@@ -822,6 +818,15 @@ void EditProfileDialog::customCursorColorChanged(const QColor &color)
     _appearanceUi->customCursorColorButton->click();
 }
 
+void EditProfileDialog::customCursorTextColorChanged(const QColor &color)
+{
+    preview(Profile::CustomCursorTextColor, color);
+    updateTempProfileProperty(Profile::CustomCursorTextColor, color);
+
+    // ensure that custom cursor colors are enabled
+    _appearanceUi->customCursorColorButton->click();
+}
+
 void EditProfileDialog::terminalMarginChanged(int margin)
 {
     preview(Profile::TerminalMargin, margin);
@@ -866,9 +871,9 @@ void EditProfileDialog::updateColorSchemeList(const QString &selectedColorScheme
 
     QStandardItem *selectedItem = nullptr;
 
-    QList<const ColorScheme *> schemeList = ColorSchemeManager::instance()->allColorSchemes();
+   const QList<const ColorScheme *> schemeList = ColorSchemeManager::instance()->allColorSchemes();
 
-    foreach (const ColorScheme *scheme, schemeList) {
+    for (const ColorScheme *scheme : schemeList) {
         QStandardItem *item = new QStandardItem(scheme->description());
         item->setData(QVariant::fromValue(scheme), Qt::UserRole + 1);
         item->setData(QVariant::fromValue(_profile->font()), Qt::UserRole + 2);
@@ -1325,7 +1330,8 @@ void EditProfileDialog::enableIfNonEmptySelection(QWidget *widget, QItemSelectio
 void EditProfileDialog::updateTransparencyWarning()
 {
     // zero or one indexes can be selected
-    foreach (const QModelIndex &index, _appearanceUi->colorSchemeList->selectionModel()->selectedIndexes()) {
+    const QModelIndexList selected = _appearanceUi->colorSchemeList->selectionModel()->selectedIndexes();
+    for (const QModelIndex &index : selected) {
         bool needTransparency = index.data(Qt::UserRole + 1).value<const ColorScheme *>()->opacity() < 1.0;
 
         if (!needTransparency) {
