@@ -495,7 +495,7 @@ void Session::run()
 
     int result = _shellProcess->start(exec, arguments, _environment);
     if (result < 0) {
-        terminalWarning(i18n("Could not start program '%1' with arguments '%2'.", exec, arguments.join(QLatin1Char(' '))));
+        terminalWarning(i18n("Could not start program '%1' with arguments '%2'.", exec, arguments.join(QLatin1String(" "))));
         terminalWarning(_shellProcess->errorString());
         return;
     }
@@ -623,7 +623,7 @@ void Session::silenceTimerDone()
     }
 
     bool hasFocus = false;
-    foreach(TerminalDisplay *display, _views) {
+    for (const TerminalDisplay *display : qAsConst(_views)) {
         if (display->hasFocus()) {
             hasFocus = true;
             break;
@@ -646,14 +646,14 @@ void Session::updateFlowControlState(bool suspended)
 {
     if (suspended) {
         if (flowControlEnabled()) {
-            foreach(TerminalDisplay * display, _views) {
+            for (TerminalDisplay *display : qAsConst(_views)) {
                 if (display->flowControlWarningEnabled()) {
                     display->outputSuspended(true);
                 }
             }
         }
     } else {
-        foreach(TerminalDisplay * display, _views) {
+        for (TerminalDisplay *display : qAsConst(_views)) {
             display->outputSuspended(false);
         }
     }
@@ -678,6 +678,10 @@ bool Session::isPrimaryScreen()
 void Session::sessionAttributeRequest(int id)
 {
     switch (id) {
+        case TextColor:
+            // Get 'TerminalDisplay' (_view) foreground color
+            emit getForegroundColor();
+            break;
         case BackgroundColor:
             // Get 'TerminalDisplay' (_view) background color
             emit getBackgroundColor();
@@ -695,7 +699,7 @@ void Session::activityStateSet(int state)
     } else if (state == NOTIFYACTIVITY) {
         // Don't notify if the terminal is active
         bool hasFocus = false;
-        foreach(TerminalDisplay *display, _views) {
+        for (const TerminalDisplay *display : qAsConst(_views)) {
             if (display->hasFocus()) {
                 hasFocus = true;
                 break;
@@ -746,7 +750,7 @@ void Session::updateTerminalSize()
     const int VIEW_COLUMNS_THRESHOLD = 2;
 
     //select largest number of lines and columns that will fit in all visible views
-    foreach(TerminalDisplay* view, _views) {
+    for (TerminalDisplay *view : qAsConst(_views)) {
         if (!view->isHidden() &&
                 view->lines() >= VIEW_LINES_THRESHOLD &&
                 view->columns() >= VIEW_COLUMNS_THRESHOLD) {
@@ -801,10 +805,10 @@ void Session::sendSignal(int signal)
     }
 }
 
-void Session::reportBackgroundColor(const QColor& c)
+void Session::reportColor(SessionAttributes r, const QColor& c)
 {
     #define to65k(a) (QStringLiteral("%1").arg(int(((a)*0xFFFF)), 4, 16, QLatin1Char('0')))
-    QString msg = QStringLiteral("\033]11;rgb:")
+    QString msg = QStringLiteral("\033]%1;rgb:").arg(r)
                 + to65k(c.redF())   + QLatin1Char('/')
                 + to65k(c.greenF()) + QLatin1Char('/')
                 + to65k(c.blueF())  + QLatin1Char('\a');
@@ -812,6 +816,16 @@ void Session::reportBackgroundColor(const QColor& c)
     #undef to65k
 }
 
+void Session::reportForegroundColor(const QColor& c)
+{
+    reportColor(SessionAttributes::TextColor, c);
+}
+
+void Session::reportBackgroundColor(const QColor& c)
+{
+    reportColor(SessionAttributes::BackgroundColor, c);
+}
+
 bool Session::kill(int signal)
 {
     if (_shellProcess->pid() <= 0) {
@@ -1154,6 +1168,8 @@ QString Session::getDynamicTitle()
     if (dir.isEmpty()) {
         // update current directory from process
         updateWorkingDirectory();
+        // Previous process may have been freed in updateSessionProcessInfo()
+        process = getProcessInfo();
         dir = process->currentDir(&ok);
     }
     if(!ok) {
@@ -1604,7 +1620,7 @@ QString Session::profile()
 void Session::setProfile(const QString &profileName)
 {
   const QList<Profile::Ptr> profiles = ProfileManager::instance()->allProfiles();
-  foreach (const Profile::Ptr &profile, profiles) {
+  for (const Profile::Ptr &profile : profiles) {
     if (profile->name() == profileName) {
       SessionManager::instance()->setSessionProfile(this, profile);
     }
@@ -1717,18 +1733,10 @@ SessionGroup::SessionGroup(QObject* parent)
 }
 SessionGroup::~SessionGroup() = default;
 
-int SessionGroup::masterMode() const
-{
-    return _masterMode;
-}
 QList<Session*> SessionGroup::sessions() const
 {
     return _sessions.keys();
 }
-bool SessionGroup::masterStatus(Session* session) const
-{
-    return _sessions[session];
-}
 
 void SessionGroup::addSession(Session* session)
 {
@@ -1751,10 +1759,7 @@ void SessionGroup::setMasterMode(int mode)
 {
     _masterMode = mode;
 }
-QList<Session*> SessionGroup::masters() const
-{
-    return _sessions.keys(true);
-}
+ 
 void SessionGroup::setMasterStatus(Session* session , bool master)
 {
     const bool wasMaster = _sessions[session];
@@ -1785,7 +1790,7 @@ void SessionGroup::forwardData(const QByteArray& data)
 
     _inForwardData = true;
     const QList<Session*> sessionsKeys = _sessions.keys();
-    foreach(Session* other, sessionsKeys) {
+    for (Session *other : sessionsKeys) {
         if (!_sessions[other]) {
             other->emulation()->sendString(data);
         }
