@@ -92,7 +92,7 @@ public:
      * Constructs a new SessionController which operates on @p session and @p view.
      */
     SessionController(Session *session, TerminalDisplay *view, QObject *parent);
-    ~SessionController() Q_DECL_OVERRIDE;
+    ~SessionController() override;
 
     /** Returns the session associated with this controller */
     QPointer<Session> session()
@@ -135,14 +135,14 @@ public:
     EditProfileDialog *profileDialogPointer();
 
     // reimplemented
-    QUrl url() const Q_DECL_OVERRIDE;
-    QString currentDir() const Q_DECL_OVERRIDE;
-    void rename() Q_DECL_OVERRIDE;
-    bool confirmClose() const Q_DECL_OVERRIDE;
+    QUrl url() const override;
+    QString currentDir() const override;
+    void rename() override;
+    bool confirmClose() const override;
     virtual bool confirmForceClose() const;
 
     // Reimplemented to watch for events happening to the view
-    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *watched, QEvent *event) override;
 
     /** Returns the set of all controllers that exist. */
     static QSet<SessionController *> allControllers()
@@ -248,6 +248,7 @@ private Q_SLOTS:
     void handleWebShortcutAction();
     void configureWebShortcuts();
     void sendSignal(QAction *action);
+    void sendForegroundColor();
     void sendBackgroundColor();
     void toggleReadOnly();
 
