@@ -1007,7 +1007,7 @@ void Vt102Emulation::reportSecondaryAttributes()
 /* DECREPTPARM – Report Terminal Parameters
     ESC [ <sol>; <par>; <nbits>; <xspeed>; <rspeed>; <clkmul>; <flags> x
 
-    http://vt100.net/docs/vt100-ug/chapter3.html
+    https://vt100.net/docs/vt100-ug/chapter3.html
 */
 void Vt102Emulation::reportTerminalParms(int p)
 {
@@ -1504,8 +1504,8 @@ char Vt102Emulation::eraseChar() const
 {
     KeyboardTranslator::Entry entry = _keyTranslator->findEntry(
         Qt::Key_Backspace,
-        nullptr,
-        nullptr);
+        Qt::NoModifier,
+        KeyboardTranslator::NoState);
     if (entry.text().count() > 0) {
         return entry.text().at(0);
     } else {
