@@ -32,7 +32,6 @@
 #include <QProxyStyle>
 #include <QStandardPaths>
 #include <QDir>
-#include <memory>
 
 // KDE
 #include <KAboutData>
@@ -108,8 +107,7 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char *argv[])
     qputenv("QT_NO_GLIB", "1");
 #endif
 
-    // Allocate QApplication on the heap for the KDBusService workaround
-    auto app = std::unique_ptr<QApplication>(new QApplication(argc, argv));
+    auto app = new QApplication(argc, argv);
     app->setStyle(new MenuStyle());
 
 #if defined(Q_OS_LINUX) && (QT_VERSION < QT_VERSION_CHECK(5, 11, 2))
@@ -151,8 +149,6 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char *argv[])
 
     QSharedPointer<QCommandLineParser> parser(new QCommandLineParser);
     parser->setApplicationDescription(about.shortDescription());
-    parser->addHelpOption();
-    parser->addVersionOption();
     about.setupCommandLine(parser.data());
 
     QStringList args = app->arguments();
@@ -167,6 +163,8 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char *argv[])
     if (!Konsole::KonsoleSettings::useSingleInstance()
         && !parser->isSet(QStringLiteral("new-tab"))) {
         startupOption = KDBusService::Multiple;
+    } else if (Konsole::KonsoleSettings::useSingleInstance()) {
+        startupOption = KDBusService::Unique;
     }
 
     atexit(deleteQApplication);
@@ -194,9 +192,8 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char *argv[])
             if (!targetDir.exists()) {
                 QDir().mkpath(targetBasePath);
             }
-            QStringList fileNames = sourceDir.entryList(
-                QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks);
-            foreach (const QString &fileName, fileNames) {
+            const QStringList fileNames = sourceDir.entryList(QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks);
+            for (const QString &fileName : fileNames) {
                 targetFilePath = targetBasePath + fileName;
                 if (!QFile::exists(targetFilePath)) {
                     QFile::copy(sourceBasePath + fileName, targetFilePath);
@@ -222,11 +219,15 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char *argv[])
         // 2. An invalid situation occurred
         const bool continueStarting = (konsoleApp.newInstance() != 0);
         if (!continueStarting) {
+            delete app;
             return 0;
         }
     }
 
+    // Since we've allocated the QApplication on the heap for the KDBusService workaround,
+    // we need to delete it manually before returning from main().
     int ret = app->exec();
+    delete app;
     return ret;
 }
 
@@ -257,7 +258,7 @@ bool shouldUseNewProcess(int argc, char *argv[])
     qtProblematicOptions << QStringLiteral("--display")
                          << QStringLiteral("--visual");
 #endif
-    foreach (const QString &option, qtProblematicOptions) {
+    for (const QString &option : qAsConst(qtProblematicOptions)) {
         if (arguments.contains(option)) {
             return true;
         }
@@ -271,7 +272,7 @@ bool shouldUseNewProcess(int argc, char *argv[])
     kdeProblematicOptions << QStringLiteral("--waitforwm");
 #endif
 
-    foreach (const QString &option, kdeProblematicOptions) {
+    for (const QString &option : qAsConst(kdeProblematicOptions)) {
         if (arguments.contains(option)) {
             return true;
         }
@@ -280,13 +281,13 @@ bool shouldUseNewProcess(int argc, char *argv[])
     // if users have explictly requested starting a new process
     // Support --nofork to retain argument compatibility with older
     // versions.
-    if (arguments.contains(QLatin1String("--separate"))
-        || arguments.contains(QLatin1String("--nofork"))) {
+    if (arguments.contains(QStringLiteral("--separate"))
+        || arguments.contains(QStringLiteral("--nofork"))) {
         return true;
     }
 
     // the only way to create new tab is to reuse existing Konsole process.
-    if (arguments.contains(QLatin1String("--new-tab"))) {
+    if (arguments.contains(QStringLiteral("--new-tab"))) {
         return false;
     }
 
